'''Handling player input and player data.'''

# Default libs #
import random

# Pygame libs #
import pygame

# Game libs #
import graphics

DOCTOR_IMAGES      = 2
DOCTOR_INSTABILITY = 4
DOCTOR_X_SPEED     = 200
DOCTOR_Y_SPEED     = 100
FRAME_SIZE         = 128 

LEFT  = 0
RIGHT = 1

class Doctor(object):
    def __init__(self, position):
        # Create sprite #
        self.spritesheet = graphics.SpriteSheet("doctor.png", (128, 128))
        self.sprite      = graphics.Sprite(self.spritesheet)
        self.sprite.add_animation("walk right", graphics.Animation([0, 1, 0, 2], [100, 100, 100, 100]))
        self.sprite.add_animation("stop right", graphics.Animation([0], [1]))
        self.sprite.add_animation("walk left",  graphics.Animation([3, 4, 3, 5], [100, 100, 100, 100]))
        self.sprite.add_animation("stop left",  graphics.Animation([3], [1]))
        
        # Initialize sprite #
        self.last_x_movement = RIGHT
        self.sprite.set_animation("stop right")
        
        # Set position #
        self.set_position(position)
    
    def draw(self, target_surface):
        frame = self.sprite.get_frame()
        frame.set_alpha(255)
        self.sprite.draw(target_surface, self.rect)
        frame.set_alpha(64)
        for count in xrange(DOCTOR_IMAGES):
            rect = pygame.rect.Rect(self.rect)
            rect.x += random.gauss(0, DOCTOR_INSTABILITY)
            rect.y += random.gauss(0, DOCTOR_INSTABILITY/2.0)
            self.sprite.draw(target_surface, rect)
    
    def calculate_next_position(self, (d_x, d_y), d_time):
        (x, y) = self.position
        new_x = x + (d_x*DOCTOR_X_SPEED*d_time)/1000.0
        new_y = y + (d_y*DOCTOR_Y_SPEED*d_time)/1000.0
        return (new_x, new_y)

    def get_position(self):
        return self.position
    
    def set_position(self, (x, y)):
        self.position = (x, y)
        self.rect     = ((x-FRAME_SIZE/2.0, y-FRAME_SIZE), (FRAME_SIZE, FRAME_SIZE))
    
    def move(self, (d_x, d_y), d_time):
        (x, y) = self.position
        new_x = x + (d_x*DOCTOR_X_SPEED*d_time)/1000.0
        new_y = y + (d_y*DOCTOR_Y_SPEED*d_time)/1000.0
        self.set_position((new_x, new_y))

    def update(self, keys, d_time):
        if keys[pygame.K_RIGHT]:
            self.sprite.set_animation("walk right")
            self.last_x_movement = RIGHT
        elif keys[pygame.K_LEFT]:
            self.sprite.set_animation("walk left")
            self.last_x_movement = LEFT
        else:
            if keys[pygame.K_UP] or keys[pygame.K_DOWN]:
                if self.last_x_movement == RIGHT:
                    self.sprite.set_animation("walk right")
                else:
                    self.sprite.set_animation("walk left")
            elif self.last_x_movement == RIGHT:
                self.sprite.set_animation("stop right")
            else:
                self.sprite.set_animation("stop left")
        self.sprite.update(d_time)
